@@ -285,8 +285,12 @@ class TemporaryDirectory(object):
                 _rm_rf(self.name)
             self._closed = True
             if _warn and _warnings.warn:
-                _warnings.warn("Implicitly cleaning up {!r}".format(self),
-                               _warnings.ResourceWarning)
+                try:
+                    _warnings.warn("Implicitly cleaning up {!r}".format(self),
+                                   _warnings.ResourceWarning)
+                except AttributeError:
+                    _warnings.warn("Implicitly cleaning up {!r}".format(self),
+                                   RuntimeWarning)
 
     def __exit__(self, exc, value, tb):
         self.cleanup()
