@@ -23,7 +23,7 @@ from .base.context import context
 from .common.compat import ensure_text_type, iteritems, open, text_type
 from .common.path import paths_equal
 from .core.prefix_data import PrefixData
-from .exceptions import CondaHistoryError, CondaUpgradeError, NotWritableError
+from .exceptions import CondaHistoryError, NotWritableError
 from .gateways.disk.update import touch
 from .models.dist import dist_str_to_quad
 from .models.version import VersionOrder, version_relation_re
@@ -255,7 +255,15 @@ class History(object):
                         "base_prefix": context.root_prefix,
                         "minimum_version": minimum_major_minor,
                     }
-                raise CondaUpgradeError(message)
+                message += dedent("""
+                To work around this restriction, one can also set the config parameter
+                'allow_conda_downgrades' to False at their own risk.
+                """)
+
+                # TODO: we need to rethink this.  It's fine as a warning to try to get users
+                #    to avoid breaking their system.  However, right now it is preventing
+                #    normal conda operation after downgrading conda.
+                # raise CondaUpgradeError(message)
 
         return res
 
